@@ -5,11 +5,11 @@ import pdb
 from mitmproxy.net.http.url import encode as urlencode
 from mitmproxy.coretypes.multidict import MultiDict
 from urllib.parse import urlparse
-from stoobly_agent.app.proxy.replay.body_parser_service import decode_response, encode_response, is_traversable
-from stoobly_agent.lib.api.interfaces.endpoints import RequestComponentName
 from typing import List, Union
 
-from stoobly_agent.lib.api.interfaces.request_show_response import RequestShowResponse
+from stoobly_agent.app.proxy.replay.body_parser_service import decode_response, encode_response, is_traversable
+from stoobly_agent.lib.api.interfaces.endpoints import RequestComponentName
+from stoobly_agent.lib.api.interfaces import RequestShowResponse
 
 class Request():
 
@@ -20,6 +20,22 @@ class Request():
   def clone(self):
     return Request(copy.deepcopy(self.request))
 
+  @property
+  def host(self):
+    return self.__url.netloc
+
+  @host.setter
+  def host(self, v):
+    self.__url = self.__url._replace(netloc=v)
+
+  @property
+  def scheme(self):
+    return self.__url.scheme
+
+  @scheme.setter
+  def scheme(self, v):
+    self.__url = self.__url._replace(scheme=v)
+
   @property
   def id(self):
     return self.request.get('id')
